#ifndef KLUMPAT__H
#define KLUMPAT__H

enum { DEBUG = 0, INFO, NOTICE, WARN, ERROR, CRIT, ALERT, EMERG };

typedef struct {
  int type;
  char * name;
  int level;
} klumpat;

/**
 * @desc create new NULL logger (works like console logger to /dev/null, but more efficient)
 * @param name name of the logger
 * @param level int
 * @return new NULL logger
 */
klumpat * kl_new(char * name, int level);

/**
 * @desc create new console logger
 * @param name name of the logger
 * @param level int
 * @return new console logger
 */
klumpat * kl_new_console(char * name, int level);

/**
 * @desc create new file logger
 * @param name name of the logger
 * @param level int
 * @param file logfile
 * @return new file logger
 */
klumpat * kl_new_file(char * name, int level, char * file);

/**
 * @desc create new meta logger
 * @param name name of the logger
 * @param level the loglevel
 * @return new meta logger
 */
klumpat * kl_new_meta(char * name, int level);

#ifdef _WANT_SYSLOG
/**
 * @desc create a new syslog logger
 * @param name name of the logger
 * @param level the loglevel
 * @param facility the logging facility
 * @return new syslog logger
 */
klumpat * kl_new_syslog(char * name, int level, int facility);
#endif

/**
 * @desc add logger to meta
 * @param meta meta logger
 * @param log logger to add to the meta logger
 */
void kl_add_logger(klumpat * meta, klumpat * log);

/**
 * @desc delete logger
 * @param logger
 */
void kl_delete(klumpat * logger);

/**
 * @desc log a message to a logger
 * @param logger the logger to log to
 * @param level the int
 * @param msg message to log to logger
 */
void kl_log(klumpat * logger, int level, char * msg);

#endif
